# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['RepoWebhookArgs', 'RepoWebhook']

@pulumi.input_type
class RepoWebhookArgs:
    def __init__(__self__, *,
                 enabled: pulumi.Input[_builtins.bool],
                 identifier: pulumi.Input[_builtins.str],
                 insecure: pulumi.Input[_builtins.bool],
                 repo_identifier: pulumi.Input[_builtins.str],
                 url: pulumi.Input[_builtins.str],
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 secret: Optional[pulumi.Input[_builtins.str]] = None,
                 triggers: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a RepoWebhook resource.
        :param pulumi.Input[_builtins.bool] enabled: Webhook enabled.
        :param pulumi.Input[_builtins.str] identifier: Identifier of the webhook.
        :param pulumi.Input[_builtins.bool] insecure: Allow insecure connections for provided webhook URL.
        :param pulumi.Input[_builtins.str] repo_identifier: Identifier of the repository.
        :param pulumi.Input[_builtins.str] url: URL that's called by the webhook.
        :param pulumi.Input[_builtins.str] description: Description of the webhook.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] secret: Webhook secret which will be used to sign the webhook payload.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] triggers: List of triggers of the webhook (keep empty for all triggers).
        """
        pulumi.set(__self__, "enabled", enabled)
        pulumi.set(__self__, "identifier", identifier)
        pulumi.set(__self__, "insecure", insecure)
        pulumi.set(__self__, "repo_identifier", repo_identifier)
        pulumi.set(__self__, "url", url)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if secret is not None:
            pulumi.set(__self__, "secret", secret)
        if triggers is not None:
            pulumi.set(__self__, "triggers", triggers)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> pulumi.Input[_builtins.bool]:
        """
        Webhook enabled.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: pulumi.Input[_builtins.bool]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Identifier of the webhook.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter
    def insecure(self) -> pulumi.Input[_builtins.bool]:
        """
        Allow insecure connections for provided webhook URL.
        """
        return pulumi.get(self, "insecure")

    @insecure.setter
    def insecure(self, value: pulumi.Input[_builtins.bool]):
        pulumi.set(self, "insecure", value)

    @_builtins.property
    @pulumi.getter(name="repoIdentifier")
    def repo_identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Identifier of the repository.
        """
        return pulumi.get(self, "repo_identifier")

    @repo_identifier.setter
    def repo_identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "repo_identifier", value)

    @_builtins.property
    @pulumi.getter
    def url(self) -> pulumi.Input[_builtins.str]:
        """
        URL that's called by the webhook.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "url", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the webhook.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def secret(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Webhook secret which will be used to sign the webhook payload.
        """
        return pulumi.get(self, "secret")

    @secret.setter
    def secret(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "secret", value)

    @_builtins.property
    @pulumi.getter
    def triggers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of triggers of the webhook (keep empty for all triggers).
        """
        return pulumi.get(self, "triggers")

    @triggers.setter
    def triggers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "triggers", value)


@pulumi.input_type
class _RepoWebhookState:
    def __init__(__self__, *,
                 created: Optional[pulumi.Input[_builtins.int]] = None,
                 created_by: Optional[pulumi.Input[_builtins.int]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 has_secret: Optional[pulumi.Input[_builtins.bool]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 insecure: Optional[pulumi.Input[_builtins.bool]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 repo_identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 secret: Optional[pulumi.Input[_builtins.str]] = None,
                 triggers: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 url: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering RepoWebhook resources.
        :param pulumi.Input[_builtins.int] created: Timestamp when the webhook was created.
        :param pulumi.Input[_builtins.int] created_by: ID of the user who created the webhook.
        :param pulumi.Input[_builtins.str] description: Description of the webhook.
        :param pulumi.Input[_builtins.bool] enabled: Webhook enabled.
        :param pulumi.Input[_builtins.bool] has_secret: Created webhook has secret encoding.
        :param pulumi.Input[_builtins.str] identifier: Identifier of the webhook.
        :param pulumi.Input[_builtins.bool] insecure: Allow insecure connections for provided webhook URL.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] repo_identifier: Identifier of the repository.
        :param pulumi.Input[_builtins.str] secret: Webhook secret which will be used to sign the webhook payload.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] triggers: List of triggers of the webhook (keep empty for all triggers).
        :param pulumi.Input[_builtins.str] url: URL that's called by the webhook.
        """
        if created is not None:
            pulumi.set(__self__, "created", created)
        if created_by is not None:
            pulumi.set(__self__, "created_by", created_by)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if has_secret is not None:
            pulumi.set(__self__, "has_secret", has_secret)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if insecure is not None:
            pulumi.set(__self__, "insecure", insecure)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if repo_identifier is not None:
            pulumi.set(__self__, "repo_identifier", repo_identifier)
        if secret is not None:
            pulumi.set(__self__, "secret", secret)
        if triggers is not None:
            pulumi.set(__self__, "triggers", triggers)
        if url is not None:
            pulumi.set(__self__, "url", url)

    @_builtins.property
    @pulumi.getter
    def created(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Timestamp when the webhook was created.
        """
        return pulumi.get(self, "created")

    @created.setter
    def created(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "created", value)

    @_builtins.property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        ID of the user who created the webhook.
        """
        return pulumi.get(self, "created_by")

    @created_by.setter
    def created_by(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "created_by", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the webhook.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Webhook enabled.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter(name="hasSecret")
    def has_secret(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Created webhook has secret encoding.
        """
        return pulumi.get(self, "has_secret")

    @has_secret.setter
    def has_secret(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "has_secret", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Identifier of the webhook.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter
    def insecure(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Allow insecure connections for provided webhook URL.
        """
        return pulumi.get(self, "insecure")

    @insecure.setter
    def insecure(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "insecure", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="repoIdentifier")
    def repo_identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Identifier of the repository.
        """
        return pulumi.get(self, "repo_identifier")

    @repo_identifier.setter
    def repo_identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "repo_identifier", value)

    @_builtins.property
    @pulumi.getter
    def secret(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Webhook secret which will be used to sign the webhook payload.
        """
        return pulumi.get(self, "secret")

    @secret.setter
    def secret(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "secret", value)

    @_builtins.property
    @pulumi.getter
    def triggers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of triggers of the webhook (keep empty for all triggers).
        """
        return pulumi.get(self, "triggers")

    @triggers.setter
    def triggers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "triggers", value)

    @_builtins.property
    @pulumi.getter
    def url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        URL that's called by the webhook.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "url", value)


@pulumi.type_token("harness:platform/repoWebhook:RepoWebhook")
class RepoWebhook(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 insecure: Optional[pulumi.Input[_builtins.bool]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 repo_identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 secret: Optional[pulumi.Input[_builtins.str]] = None,
                 triggers: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 url: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Resource for creating a Harness Repo Webhook.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: Description of the webhook.
        :param pulumi.Input[_builtins.bool] enabled: Webhook enabled.
        :param pulumi.Input[_builtins.str] identifier: Identifier of the webhook.
        :param pulumi.Input[_builtins.bool] insecure: Allow insecure connections for provided webhook URL.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] repo_identifier: Identifier of the repository.
        :param pulumi.Input[_builtins.str] secret: Webhook secret which will be used to sign the webhook payload.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] triggers: List of triggers of the webhook (keep empty for all triggers).
        :param pulumi.Input[_builtins.str] url: URL that's called by the webhook.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RepoWebhookArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating a Harness Repo Webhook.

        :param str resource_name: The name of the resource.
        :param RepoWebhookArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RepoWebhookArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 insecure: Optional[pulumi.Input[_builtins.bool]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 repo_identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 secret: Optional[pulumi.Input[_builtins.str]] = None,
                 triggers: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 url: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RepoWebhookArgs.__new__(RepoWebhookArgs)

            __props__.__dict__["description"] = description
            if enabled is None and not opts.urn:
                raise TypeError("Missing required property 'enabled'")
            __props__.__dict__["enabled"] = enabled
            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__.__dict__["identifier"] = identifier
            if insecure is None and not opts.urn:
                raise TypeError("Missing required property 'insecure'")
            __props__.__dict__["insecure"] = insecure
            __props__.__dict__["org_id"] = org_id
            __props__.__dict__["project_id"] = project_id
            if repo_identifier is None and not opts.urn:
                raise TypeError("Missing required property 'repo_identifier'")
            __props__.__dict__["repo_identifier"] = repo_identifier
            __props__.__dict__["secret"] = None if secret is None else pulumi.Output.secret(secret)
            __props__.__dict__["triggers"] = triggers
            if url is None and not opts.urn:
                raise TypeError("Missing required property 'url'")
            __props__.__dict__["url"] = url
            __props__.__dict__["created"] = None
            __props__.__dict__["created_by"] = None
            __props__.__dict__["has_secret"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["secret"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(RepoWebhook, __self__).__init__(
            'harness:platform/repoWebhook:RepoWebhook',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created: Optional[pulumi.Input[_builtins.int]] = None,
            created_by: Optional[pulumi.Input[_builtins.int]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            has_secret: Optional[pulumi.Input[_builtins.bool]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            insecure: Optional[pulumi.Input[_builtins.bool]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            repo_identifier: Optional[pulumi.Input[_builtins.str]] = None,
            secret: Optional[pulumi.Input[_builtins.str]] = None,
            triggers: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            url: Optional[pulumi.Input[_builtins.str]] = None) -> 'RepoWebhook':
        """
        Get an existing RepoWebhook resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.int] created: Timestamp when the webhook was created.
        :param pulumi.Input[_builtins.int] created_by: ID of the user who created the webhook.
        :param pulumi.Input[_builtins.str] description: Description of the webhook.
        :param pulumi.Input[_builtins.bool] enabled: Webhook enabled.
        :param pulumi.Input[_builtins.bool] has_secret: Created webhook has secret encoding.
        :param pulumi.Input[_builtins.str] identifier: Identifier of the webhook.
        :param pulumi.Input[_builtins.bool] insecure: Allow insecure connections for provided webhook URL.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] repo_identifier: Identifier of the repository.
        :param pulumi.Input[_builtins.str] secret: Webhook secret which will be used to sign the webhook payload.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] triggers: List of triggers of the webhook (keep empty for all triggers).
        :param pulumi.Input[_builtins.str] url: URL that's called by the webhook.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RepoWebhookState.__new__(_RepoWebhookState)

        __props__.__dict__["created"] = created
        __props__.__dict__["created_by"] = created_by
        __props__.__dict__["description"] = description
        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["has_secret"] = has_secret
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["insecure"] = insecure
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["repo_identifier"] = repo_identifier
        __props__.__dict__["secret"] = secret
        __props__.__dict__["triggers"] = triggers
        __props__.__dict__["url"] = url
        return RepoWebhook(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def created(self) -> pulumi.Output[_builtins.int]:
        """
        Timestamp when the webhook was created.
        """
        return pulumi.get(self, "created")

    @_builtins.property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> pulumi.Output[_builtins.int]:
        """
        ID of the user who created the webhook.
        """
        return pulumi.get(self, "created_by")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of the webhook.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Webhook enabled.
        """
        return pulumi.get(self, "enabled")

    @_builtins.property
    @pulumi.getter(name="hasSecret")
    def has_secret(self) -> pulumi.Output[_builtins.bool]:
        """
        Created webhook has secret encoding.
        """
        return pulumi.get(self, "has_secret")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Identifier of the webhook.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def insecure(self) -> pulumi.Output[_builtins.bool]:
        """
        Allow insecure connections for provided webhook URL.
        """
        return pulumi.get(self, "insecure")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="repoIdentifier")
    def repo_identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Identifier of the repository.
        """
        return pulumi.get(self, "repo_identifier")

    @_builtins.property
    @pulumi.getter
    def secret(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Webhook secret which will be used to sign the webhook payload.
        """
        return pulumi.get(self, "secret")

    @_builtins.property
    @pulumi.getter
    def triggers(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        List of triggers of the webhook (keep empty for all triggers).
        """
        return pulumi.get(self, "triggers")

    @_builtins.property
    @pulumi.getter
    def url(self) -> pulumi.Output[_builtins.str]:
        """
        URL that's called by the webhook.
        """
        return pulumi.get(self, "url")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetUserResult',
    'AwaitableGetUserResult',
    'get_user',
    'get_user_output',
]

@pulumi.output_type
class GetUserResult:
    """
    A collection of values returned by getUser.
    """
    def __init__(__self__, disabled=None, email=None, externally_managed=None, id=None, identifier=None, locked=None, name=None, org_id=None, project_id=None):
        if disabled and not isinstance(disabled, bool):
            raise TypeError("Expected argument 'disabled' to be a bool")
        pulumi.set(__self__, "disabled", disabled)
        if email and not isinstance(email, str):
            raise TypeError("Expected argument 'email' to be a str")
        pulumi.set(__self__, "email", email)
        if externally_managed and not isinstance(externally_managed, bool):
            raise TypeError("Expected argument 'externally_managed' to be a bool")
        pulumi.set(__self__, "externally_managed", externally_managed)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if locked and not isinstance(locked, bool):
            raise TypeError("Expected argument 'locked' to be a bool")
        pulumi.set(__self__, "locked", locked)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)

    @_builtins.property
    @pulumi.getter
    def disabled(self) -> _builtins.bool:
        """
        Whether or not the user account is disabled.
        """
        return pulumi.get(self, "disabled")

    @_builtins.property
    @pulumi.getter
    def email(self) -> _builtins.str:
        """
        The email of the user.
        """
        return pulumi.get(self, "email")

    @_builtins.property
    @pulumi.getter(name="externallyManaged")
    def externally_managed(self) -> _builtins.bool:
        """
        Whether or not the user account is externally managed.
        """
        return pulumi.get(self, "externally_managed")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> _builtins.str:
        """
        Unique identifier of the user.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def locked(self) -> _builtins.bool:
        """
        Whether or not the user account is locked.
        """
        return pulumi.get(self, "locked")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Name of the user.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[_builtins.str]:
        """
        Organization identifier of the user.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        """
        Project identifier of the user.
        """
        return pulumi.get(self, "project_id")


class AwaitableGetUserResult(GetUserResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetUserResult(
            disabled=self.disabled,
            email=self.email,
            externally_managed=self.externally_managed,
            id=self.id,
            identifier=self.identifier,
            locked=self.locked,
            name=self.name,
            org_id=self.org_id,
            project_id=self.project_id)


def get_user(email: Optional[_builtins.str] = None,
             org_id: Optional[_builtins.str] = None,
             project_id: Optional[_builtins.str] = None,
             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetUserResult:
    """
    Data source for retrieving the user based on the API key.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    example = harness.platform.get_user(org_id="org_id",
        project_id="project_id",
        email="john.doe@harness.io")
    ```


    :param _builtins.str email: The email of the user.
    :param _builtins.str org_id: Organization identifier of the user.
    :param _builtins.str project_id: Project identifier of the user.
    """
    __args__ = dict()
    __args__['email'] = email
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getUser:getUser', __args__, opts=opts, typ=GetUserResult).value

    return AwaitableGetUserResult(
        disabled=pulumi.get(__ret__, 'disabled'),
        email=pulumi.get(__ret__, 'email'),
        externally_managed=pulumi.get(__ret__, 'externally_managed'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        locked=pulumi.get(__ret__, 'locked'),
        name=pulumi.get(__ret__, 'name'),
        org_id=pulumi.get(__ret__, 'org_id'),
        project_id=pulumi.get(__ret__, 'project_id'))
def get_user_output(email: Optional[pulumi.Input[_builtins.str]] = None,
                    org_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                    project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetUserResult]:
    """
    Data source for retrieving the user based on the API key.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    example = harness.platform.get_user(org_id="org_id",
        project_id="project_id",
        email="john.doe@harness.io")
    ```


    :param _builtins.str email: The email of the user.
    :param _builtins.str org_id: Organization identifier of the user.
    :param _builtins.str project_id: Project identifier of the user.
    """
    __args__ = dict()
    __args__['email'] = email
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getUser:getUser', __args__, opts=opts, typ=GetUserResult)
    return __ret__.apply(lambda __response__: GetUserResult(
        disabled=pulumi.get(__response__, 'disabled'),
        email=pulumi.get(__response__, 'email'),
        externally_managed=pulumi.get(__response__, 'externally_managed'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        locked=pulumi.get(__response__, 'locked'),
        name=pulumi.get(__response__, 'name'),
        org_id=pulumi.get(__response__, 'org_id'),
        project_id=pulumi.get(__response__, 'project_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetInfrastructureV2Result',
    'AwaitableGetInfrastructureV2Result',
    'get_infrastructure_v2',
    'get_infrastructure_v2_output',
]

@pulumi.output_type
class GetInfrastructureV2Result:
    """
    A collection of values returned by getInfrastructureV2.
    """
    def __init__(__self__, annotation=None, containers=None, created_at=None, created_by=None, description=None, environment_id=None, id=None, identifier=None, identity=None, image_registries=None, infra_id=None, infra_scope=None, infra_type=None, insecure_skip_verify=None, is_ai_enabled=None, is_chaos_enabled=None, label=None, last_heartbeat=None, last_workflow_timestamp=None, mtls=None, name=None, namespace=None, no_of_schedules=None, no_of_workflows=None, node_selector=None, org_id=None, project_id=None, proxy=None, run_as_group=None, run_as_user=None, service_account=None, status=None, tags=None, tolerations=None, update_status=None, updated_at=None, updated_by=None, volume_mounts=None, volumes=None):
        if annotation and not isinstance(annotation, dict):
            raise TypeError("Expected argument 'annotation' to be a dict")
        pulumi.set(__self__, "annotation", annotation)
        if containers and not isinstance(containers, str):
            raise TypeError("Expected argument 'containers' to be a str")
        pulumi.set(__self__, "containers", containers)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if created_by and not isinstance(created_by, str):
            raise TypeError("Expected argument 'created_by' to be a str")
        pulumi.set(__self__, "created_by", created_by)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if environment_id and not isinstance(environment_id, str):
            raise TypeError("Expected argument 'environment_id' to be a str")
        pulumi.set(__self__, "environment_id", environment_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if identity and not isinstance(identity, str):
            raise TypeError("Expected argument 'identity' to be a str")
        pulumi.set(__self__, "identity", identity)
        if image_registries and not isinstance(image_registries, list):
            raise TypeError("Expected argument 'image_registries' to be a list")
        pulumi.set(__self__, "image_registries", image_registries)
        if infra_id and not isinstance(infra_id, str):
            raise TypeError("Expected argument 'infra_id' to be a str")
        pulumi.set(__self__, "infra_id", infra_id)
        if infra_scope and not isinstance(infra_scope, str):
            raise TypeError("Expected argument 'infra_scope' to be a str")
        pulumi.set(__self__, "infra_scope", infra_scope)
        if infra_type and not isinstance(infra_type, str):
            raise TypeError("Expected argument 'infra_type' to be a str")
        pulumi.set(__self__, "infra_type", infra_type)
        if insecure_skip_verify and not isinstance(insecure_skip_verify, bool):
            raise TypeError("Expected argument 'insecure_skip_verify' to be a bool")
        pulumi.set(__self__, "insecure_skip_verify", insecure_skip_verify)
        if is_ai_enabled and not isinstance(is_ai_enabled, bool):
            raise TypeError("Expected argument 'is_ai_enabled' to be a bool")
        pulumi.set(__self__, "is_ai_enabled", is_ai_enabled)
        if is_chaos_enabled and not isinstance(is_chaos_enabled, bool):
            raise TypeError("Expected argument 'is_chaos_enabled' to be a bool")
        pulumi.set(__self__, "is_chaos_enabled", is_chaos_enabled)
        if label and not isinstance(label, dict):
            raise TypeError("Expected argument 'label' to be a dict")
        pulumi.set(__self__, "label", label)
        if last_heartbeat and not isinstance(last_heartbeat, int):
            raise TypeError("Expected argument 'last_heartbeat' to be a int")
        pulumi.set(__self__, "last_heartbeat", last_heartbeat)
        if last_workflow_timestamp and not isinstance(last_workflow_timestamp, str):
            raise TypeError("Expected argument 'last_workflow_timestamp' to be a str")
        pulumi.set(__self__, "last_workflow_timestamp", last_workflow_timestamp)
        if mtls and not isinstance(mtls, dict):
            raise TypeError("Expected argument 'mtls' to be a dict")
        pulumi.set(__self__, "mtls", mtls)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if namespace and not isinstance(namespace, str):
            raise TypeError("Expected argument 'namespace' to be a str")
        pulumi.set(__self__, "namespace", namespace)
        if no_of_schedules and not isinstance(no_of_schedules, int):
            raise TypeError("Expected argument 'no_of_schedules' to be a int")
        pulumi.set(__self__, "no_of_schedules", no_of_schedules)
        if no_of_workflows and not isinstance(no_of_workflows, int):
            raise TypeError("Expected argument 'no_of_workflows' to be a int")
        pulumi.set(__self__, "no_of_workflows", no_of_workflows)
        if node_selector and not isinstance(node_selector, dict):
            raise TypeError("Expected argument 'node_selector' to be a dict")
        pulumi.set(__self__, "node_selector", node_selector)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if proxy and not isinstance(proxy, dict):
            raise TypeError("Expected argument 'proxy' to be a dict")
        pulumi.set(__self__, "proxy", proxy)
        if run_as_group and not isinstance(run_as_group, int):
            raise TypeError("Expected argument 'run_as_group' to be a int")
        pulumi.set(__self__, "run_as_group", run_as_group)
        if run_as_user and not isinstance(run_as_user, int):
            raise TypeError("Expected argument 'run_as_user' to be a int")
        pulumi.set(__self__, "run_as_user", run_as_user)
        if service_account and not isinstance(service_account, str):
            raise TypeError("Expected argument 'service_account' to be a str")
        pulumi.set(__self__, "service_account", service_account)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if tolerations and not isinstance(tolerations, list):
            raise TypeError("Expected argument 'tolerations' to be a list")
        pulumi.set(__self__, "tolerations", tolerations)
        if update_status and not isinstance(update_status, str):
            raise TypeError("Expected argument 'update_status' to be a str")
        pulumi.set(__self__, "update_status", update_status)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)
        if updated_by and not isinstance(updated_by, str):
            raise TypeError("Expected argument 'updated_by' to be a str")
        pulumi.set(__self__, "updated_by", updated_by)
        if volume_mounts and not isinstance(volume_mounts, list):
            raise TypeError("Expected argument 'volume_mounts' to be a list")
        pulumi.set(__self__, "volume_mounts", volume_mounts)
        if volumes and not isinstance(volumes, list):
            raise TypeError("Expected argument 'volumes' to be a list")
        pulumi.set(__self__, "volumes", volumes)

    @_builtins.property
    @pulumi.getter
    def annotation(self) -> Mapping[str, _builtins.str]:
        return pulumi.get(self, "annotation")

    @_builtins.property
    @pulumi.getter
    def containers(self) -> _builtins.str:
        """
        List of containers in the infrastructure.
        """
        return pulumi.get(self, "containers")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> _builtins.str:
        """
        Created at of the infrastructure.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> _builtins.str:
        """
        Created by of the infrastructure.
        """
        return pulumi.get(self, "created_by")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Description of the infrastructure.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="environmentId")
    def environment_id(self) -> _builtins.str:
        """
        The ID of the environment.
        """
        return pulumi.get(self, "environment_id")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> _builtins.str:
        """
        Identifier of the infrastructure.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def identity(self) -> _builtins.str:
        """
        Identity of the infrastructure.
        """
        return pulumi.get(self, "identity")

    @_builtins.property
    @pulumi.getter(name="imageRegistries")
    def image_registries(self) -> Sequence['outputs.GetInfrastructureV2ImageRegistryResult']:
        """
        Configuration for the container image registry.
        """
        return pulumi.get(self, "image_registries")

    @_builtins.property
    @pulumi.getter(name="infraId")
    def infra_id(self) -> _builtins.str:
        """
        The ID of the infrastructure.
        """
        return pulumi.get(self, "infra_id")

    @_builtins.property
    @pulumi.getter(name="infraScope")
    def infra_scope(self) -> _builtins.str:
        """
        Scope of the infrastructure.
        """
        return pulumi.get(self, "infra_scope")

    @_builtins.property
    @pulumi.getter(name="infraType")
    def infra_type(self) -> _builtins.str:
        """
        Type of the infrastructure.
        """
        return pulumi.get(self, "infra_type")

    @_builtins.property
    @pulumi.getter(name="insecureSkipVerify")
    def insecure_skip_verify(self) -> _builtins.bool:
        return pulumi.get(self, "insecure_skip_verify")

    @_builtins.property
    @pulumi.getter(name="isAiEnabled")
    def is_ai_enabled(self) -> _builtins.bool:
        return pulumi.get(self, "is_ai_enabled")

    @_builtins.property
    @pulumi.getter(name="isChaosEnabled")
    def is_chaos_enabled(self) -> _builtins.bool:
        return pulumi.get(self, "is_chaos_enabled")

    @_builtins.property
    @pulumi.getter
    def label(self) -> Mapping[str, _builtins.str]:
        return pulumi.get(self, "label")

    @_builtins.property
    @pulumi.getter(name="lastHeartbeat")
    def last_heartbeat(self) -> _builtins.int:
        """
        Last heartbeat of the infrastructure.
        """
        return pulumi.get(self, "last_heartbeat")

    @_builtins.property
    @pulumi.getter(name="lastWorkflowTimestamp")
    def last_workflow_timestamp(self) -> _builtins.str:
        """
        Last workflow timestamp of the infrastructure.
        """
        return pulumi.get(self, "last_workflow_timestamp")

    @_builtins.property
    @pulumi.getter
    def mtls(self) -> Optional['outputs.GetInfrastructureV2MtlsResult']:
        """
        mTLS configuration for the infrastructure.
        """
        return pulumi.get(self, "mtls")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Name of the infrastructure.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def namespace(self) -> _builtins.str:
        """
        Kubernetes namespace for the infrastructure.
        """
        return pulumi.get(self, "namespace")

    @_builtins.property
    @pulumi.getter(name="noOfSchedules")
    def no_of_schedules(self) -> _builtins.int:
        """
        Number of schedules for the infrastructure.
        """
        return pulumi.get(self, "no_of_schedules")

    @_builtins.property
    @pulumi.getter(name="noOfWorkflows")
    def no_of_workflows(self) -> _builtins.int:
        """
        Number of workflows for the infrastructure.
        """
        return pulumi.get(self, "no_of_workflows")

    @_builtins.property
    @pulumi.getter(name="nodeSelector")
    def node_selector(self) -> Mapping[str, _builtins.str]:
        return pulumi.get(self, "node_selector")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> _builtins.str:
        """
        The ID of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> _builtins.str:
        """
        The ID of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def proxy(self) -> Optional['outputs.GetInfrastructureV2ProxyResult']:
        """
        Proxy configuration for the infrastructure.
        """
        return pulumi.get(self, "proxy")

    @_builtins.property
    @pulumi.getter(name="runAsGroup")
    def run_as_group(self) -> _builtins.int:
        return pulumi.get(self, "run_as_group")

    @_builtins.property
    @pulumi.getter(name="runAsUser")
    def run_as_user(self) -> _builtins.int:
        return pulumi.get(self, "run_as_user")

    @_builtins.property
    @pulumi.getter(name="serviceAccount")
    def service_account(self) -> _builtins.str:
        """
        Service account used by the infrastructure.
        """
        return pulumi.get(self, "service_account")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        Status of the infrastructure.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Sequence[_builtins.str]:
        """
        Tags of the infrastructure.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter
    def tolerations(self) -> Optional[Sequence['outputs.GetInfrastructureV2TolerationResult']]:
        """
        If specified, the pod's tolerations.
        """
        return pulumi.get(self, "tolerations")

    @_builtins.property
    @pulumi.getter(name="updateStatus")
    def update_status(self) -> _builtins.str:
        """
        Update status of the infrastructure.
        """
        return pulumi.get(self, "update_status")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> _builtins.str:
        """
        Updated at of the infrastructure.
        """
        return pulumi.get(self, "updated_at")

    @_builtins.property
    @pulumi.getter(name="updatedBy")
    def updated_by(self) -> _builtins.str:
        """
        Updated by of the infrastructure.
        """
        return pulumi.get(self, "updated_by")

    @_builtins.property
    @pulumi.getter(name="volumeMounts")
    def volume_mounts(self) -> Optional[Sequence['outputs.GetInfrastructureV2VolumeMountResult']]:
        """
        Volume mounts for the container.
        """
        return pulumi.get(self, "volume_mounts")

    @_builtins.property
    @pulumi.getter
    def volumes(self) -> Optional[Sequence['outputs.GetInfrastructureV2VolumeResult']]:
        """
        Volumes to be created in the infrastructure.
        """
        return pulumi.get(self, "volumes")


class AwaitableGetInfrastructureV2Result(GetInfrastructureV2Result):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInfrastructureV2Result(
            annotation=self.annotation,
            containers=self.containers,
            created_at=self.created_at,
            created_by=self.created_by,
            description=self.description,
            environment_id=self.environment_id,
            id=self.id,
            identifier=self.identifier,
            identity=self.identity,
            image_registries=self.image_registries,
            infra_id=self.infra_id,
            infra_scope=self.infra_scope,
            infra_type=self.infra_type,
            insecure_skip_verify=self.insecure_skip_verify,
            is_ai_enabled=self.is_ai_enabled,
            is_chaos_enabled=self.is_chaos_enabled,
            label=self.label,
            last_heartbeat=self.last_heartbeat,
            last_workflow_timestamp=self.last_workflow_timestamp,
            mtls=self.mtls,
            name=self.name,
            namespace=self.namespace,
            no_of_schedules=self.no_of_schedules,
            no_of_workflows=self.no_of_workflows,
            node_selector=self.node_selector,
            org_id=self.org_id,
            project_id=self.project_id,
            proxy=self.proxy,
            run_as_group=self.run_as_group,
            run_as_user=self.run_as_user,
            service_account=self.service_account,
            status=self.status,
            tags=self.tags,
            tolerations=self.tolerations,
            update_status=self.update_status,
            updated_at=self.updated_at,
            updated_by=self.updated_by,
            volume_mounts=self.volume_mounts,
            volumes=self.volumes)


def get_infrastructure_v2(environment_id: Optional[_builtins.str] = None,
                          image_registries: Optional[Sequence[Union['GetInfrastructureV2ImageRegistryArgs', 'GetInfrastructureV2ImageRegistryArgsDict']]] = None,
                          infra_id: Optional[_builtins.str] = None,
                          mtls: Optional[Union['GetInfrastructureV2MtlsArgs', 'GetInfrastructureV2MtlsArgsDict']] = None,
                          org_id: Optional[_builtins.str] = None,
                          project_id: Optional[_builtins.str] = None,
                          proxy: Optional[Union['GetInfrastructureV2ProxyArgs', 'GetInfrastructureV2ProxyArgsDict']] = None,
                          tolerations: Optional[Sequence[Union['GetInfrastructureV2TolerationArgs', 'GetInfrastructureV2TolerationArgsDict']]] = None,
                          volume_mounts: Optional[Sequence[Union['GetInfrastructureV2VolumeMountArgs', 'GetInfrastructureV2VolumeMountArgsDict']]] = None,
                          volumes: Optional[Sequence[Union['GetInfrastructureV2VolumeArgs', 'GetInfrastructureV2VolumeArgsDict']]] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetInfrastructureV2Result:
    """
    Data source for retrieving a Harness Chaos Infrastructure V2.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    # Data source to fetch a specific agent by name
    by_name = harness.service.get_discovery_agent(name="example-agent",
        org_identifier=org_identifier,
        project_identifier=project_identifier,
        environment_identifier=environment_identifier)
    pulumi.export("agentDetailsByName", by_name)
    # Data source to fetch a specific agent by identity
    by_identity = harness.service.get_discovery_agent(identity="example-infra",
        org_identifier=org_identifier,
        project_identifier=project_identifier,
        environment_identifier=environment_identifier)
    pulumi.export("agentDetailsByIdentity", by_identity)
    ```


    :param _builtins.str environment_id: The ID of the environment.
    :param Sequence[Union['GetInfrastructureV2ImageRegistryArgs', 'GetInfrastructureV2ImageRegistryArgsDict']] image_registries: Configuration for the container image registry.
    :param _builtins.str infra_id: The ID of the infrastructure.
    :param Union['GetInfrastructureV2MtlsArgs', 'GetInfrastructureV2MtlsArgsDict'] mtls: mTLS configuration for the infrastructure.
    :param _builtins.str org_id: The ID of the organization.
    :param _builtins.str project_id: The ID of the project.
    :param Union['GetInfrastructureV2ProxyArgs', 'GetInfrastructureV2ProxyArgsDict'] proxy: Proxy configuration for the infrastructure.
    :param Sequence[Union['GetInfrastructureV2TolerationArgs', 'GetInfrastructureV2TolerationArgsDict']] tolerations: If specified, the pod's tolerations.
    :param Sequence[Union['GetInfrastructureV2VolumeMountArgs', 'GetInfrastructureV2VolumeMountArgsDict']] volume_mounts: Volume mounts for the container.
    :param Sequence[Union['GetInfrastructureV2VolumeArgs', 'GetInfrastructureV2VolumeArgsDict']] volumes: Volumes to be created in the infrastructure.
    """
    __args__ = dict()
    __args__['environmentId'] = environment_id
    __args__['imageRegistries'] = image_registries
    __args__['infraId'] = infra_id
    __args__['mtls'] = mtls
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    __args__['proxy'] = proxy
    __args__['tolerations'] = tolerations
    __args__['volumeMounts'] = volume_mounts
    __args__['volumes'] = volumes
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:chaos/getInfrastructureV2:getInfrastructureV2', __args__, opts=opts, typ=GetInfrastructureV2Result).value

    return AwaitableGetInfrastructureV2Result(
        annotation=pulumi.get(__ret__, 'annotation'),
        containers=pulumi.get(__ret__, 'containers'),
        created_at=pulumi.get(__ret__, 'created_at'),
        created_by=pulumi.get(__ret__, 'created_by'),
        description=pulumi.get(__ret__, 'description'),
        environment_id=pulumi.get(__ret__, 'environment_id'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        identity=pulumi.get(__ret__, 'identity'),
        image_registries=pulumi.get(__ret__, 'image_registries'),
        infra_id=pulumi.get(__ret__, 'infra_id'),
        infra_scope=pulumi.get(__ret__, 'infra_scope'),
        infra_type=pulumi.get(__ret__, 'infra_type'),
        insecure_skip_verify=pulumi.get(__ret__, 'insecure_skip_verify'),
        is_ai_enabled=pulumi.get(__ret__, 'is_ai_enabled'),
        is_chaos_enabled=pulumi.get(__ret__, 'is_chaos_enabled'),
        label=pulumi.get(__ret__, 'label'),
        last_heartbeat=pulumi.get(__ret__, 'last_heartbeat'),
        last_workflow_timestamp=pulumi.get(__ret__, 'last_workflow_timestamp'),
        mtls=pulumi.get(__ret__, 'mtls'),
        name=pulumi.get(__ret__, 'name'),
        namespace=pulumi.get(__ret__, 'namespace'),
        no_of_schedules=pulumi.get(__ret__, 'no_of_schedules'),
        no_of_workflows=pulumi.get(__ret__, 'no_of_workflows'),
        node_selector=pulumi.get(__ret__, 'node_selector'),
        org_id=pulumi.get(__ret__, 'org_id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        proxy=pulumi.get(__ret__, 'proxy'),
        run_as_group=pulumi.get(__ret__, 'run_as_group'),
        run_as_user=pulumi.get(__ret__, 'run_as_user'),
        service_account=pulumi.get(__ret__, 'service_account'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        tolerations=pulumi.get(__ret__, 'tolerations'),
        update_status=pulumi.get(__ret__, 'update_status'),
        updated_at=pulumi.get(__ret__, 'updated_at'),
        updated_by=pulumi.get(__ret__, 'updated_by'),
        volume_mounts=pulumi.get(__ret__, 'volume_mounts'),
        volumes=pulumi.get(__ret__, 'volumes'))
def get_infrastructure_v2_output(environment_id: Optional[pulumi.Input[_builtins.str]] = None,
                                 image_registries: Optional[pulumi.Input[Optional[Sequence[Union['GetInfrastructureV2ImageRegistryArgs', 'GetInfrastructureV2ImageRegistryArgsDict']]]]] = None,
                                 infra_id: Optional[pulumi.Input[_builtins.str]] = None,
                                 mtls: Optional[pulumi.Input[Optional[Union['GetInfrastructureV2MtlsArgs', 'GetInfrastructureV2MtlsArgsDict']]]] = None,
                                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                                 proxy: Optional[pulumi.Input[Optional[Union['GetInfrastructureV2ProxyArgs', 'GetInfrastructureV2ProxyArgsDict']]]] = None,
                                 tolerations: Optional[pulumi.Input[Optional[Sequence[Union['GetInfrastructureV2TolerationArgs', 'GetInfrastructureV2TolerationArgsDict']]]]] = None,
                                 volume_mounts: Optional[pulumi.Input[Optional[Sequence[Union['GetInfrastructureV2VolumeMountArgs', 'GetInfrastructureV2VolumeMountArgsDict']]]]] = None,
                                 volumes: Optional[pulumi.Input[Optional[Sequence[Union['GetInfrastructureV2VolumeArgs', 'GetInfrastructureV2VolumeArgsDict']]]]] = None,
                                 opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetInfrastructureV2Result]:
    """
    Data source for retrieving a Harness Chaos Infrastructure V2.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    # Data source to fetch a specific agent by name
    by_name = harness.service.get_discovery_agent(name="example-agent",
        org_identifier=org_identifier,
        project_identifier=project_identifier,
        environment_identifier=environment_identifier)
    pulumi.export("agentDetailsByName", by_name)
    # Data source to fetch a specific agent by identity
    by_identity = harness.service.get_discovery_agent(identity="example-infra",
        org_identifier=org_identifier,
        project_identifier=project_identifier,
        environment_identifier=environment_identifier)
    pulumi.export("agentDetailsByIdentity", by_identity)
    ```


    :param _builtins.str environment_id: The ID of the environment.
    :param Sequence[Union['GetInfrastructureV2ImageRegistryArgs', 'GetInfrastructureV2ImageRegistryArgsDict']] image_registries: Configuration for the container image registry.
    :param _builtins.str infra_id: The ID of the infrastructure.
    :param Union['GetInfrastructureV2MtlsArgs', 'GetInfrastructureV2MtlsArgsDict'] mtls: mTLS configuration for the infrastructure.
    :param _builtins.str org_id: The ID of the organization.
    :param _builtins.str project_id: The ID of the project.
    :param Union['GetInfrastructureV2ProxyArgs', 'GetInfrastructureV2ProxyArgsDict'] proxy: Proxy configuration for the infrastructure.
    :param Sequence[Union['GetInfrastructureV2TolerationArgs', 'GetInfrastructureV2TolerationArgsDict']] tolerations: If specified, the pod's tolerations.
    :param Sequence[Union['GetInfrastructureV2VolumeMountArgs', 'GetInfrastructureV2VolumeMountArgsDict']] volume_mounts: Volume mounts for the container.
    :param Sequence[Union['GetInfrastructureV2VolumeArgs', 'GetInfrastructureV2VolumeArgsDict']] volumes: Volumes to be created in the infrastructure.
    """
    __args__ = dict()
    __args__['environmentId'] = environment_id
    __args__['imageRegistries'] = image_registries
    __args__['infraId'] = infra_id
    __args__['mtls'] = mtls
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    __args__['proxy'] = proxy
    __args__['tolerations'] = tolerations
    __args__['volumeMounts'] = volume_mounts
    __args__['volumes'] = volumes
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:chaos/getInfrastructureV2:getInfrastructureV2', __args__, opts=opts, typ=GetInfrastructureV2Result)
    return __ret__.apply(lambda __response__: GetInfrastructureV2Result(
        annotation=pulumi.get(__response__, 'annotation'),
        containers=pulumi.get(__response__, 'containers'),
        created_at=pulumi.get(__response__, 'created_at'),
        created_by=pulumi.get(__response__, 'created_by'),
        description=pulumi.get(__response__, 'description'),
        environment_id=pulumi.get(__response__, 'environment_id'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        identity=pulumi.get(__response__, 'identity'),
        image_registries=pulumi.get(__response__, 'image_registries'),
        infra_id=pulumi.get(__response__, 'infra_id'),
        infra_scope=pulumi.get(__response__, 'infra_scope'),
        infra_type=pulumi.get(__response__, 'infra_type'),
        insecure_skip_verify=pulumi.get(__response__, 'insecure_skip_verify'),
        is_ai_enabled=pulumi.get(__response__, 'is_ai_enabled'),
        is_chaos_enabled=pulumi.get(__response__, 'is_chaos_enabled'),
        label=pulumi.get(__response__, 'label'),
        last_heartbeat=pulumi.get(__response__, 'last_heartbeat'),
        last_workflow_timestamp=pulumi.get(__response__, 'last_workflow_timestamp'),
        mtls=pulumi.get(__response__, 'mtls'),
        name=pulumi.get(__response__, 'name'),
        namespace=pulumi.get(__response__, 'namespace'),
        no_of_schedules=pulumi.get(__response__, 'no_of_schedules'),
        no_of_workflows=pulumi.get(__response__, 'no_of_workflows'),
        node_selector=pulumi.get(__response__, 'node_selector'),
        org_id=pulumi.get(__response__, 'org_id'),
        project_id=pulumi.get(__response__, 'project_id'),
        proxy=pulumi.get(__response__, 'proxy'),
        run_as_group=pulumi.get(__response__, 'run_as_group'),
        run_as_user=pulumi.get(__response__, 'run_as_user'),
        service_account=pulumi.get(__response__, 'service_account'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        tolerations=pulumi.get(__response__, 'tolerations'),
        update_status=pulumi.get(__response__, 'update_status'),
        updated_at=pulumi.get(__response__, 'updated_at'),
        updated_by=pulumi.get(__response__, 'updated_by'),
        volume_mounts=pulumi.get(__response__, 'volume_mounts'),
        volumes=pulumi.get(__response__, 'volumes')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DbSchemaArgs', 'DbSchema']

@pulumi.input_type
class DbSchemaArgs:
    def __init__(__self__, *,
                 identifier: pulumi.Input[_builtins.str],
                 org_id: pulumi.Input[_builtins.str],
                 project_id: pulumi.Input[_builtins.str],
                 changelog_script: Optional[pulumi.Input['DbSchemaChangelogScriptArgs']] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 migration_type: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 schema_source: Optional[pulumi.Input['DbSchemaSchemaSourceArgs']] = None,
                 service: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a DbSchema resource.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input['DbSchemaChangelogScriptArgs'] changelog_script: Configuration to clone changeSets using script
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.str] migration_type: DB Migration tool type. Valid values are: Liquibase, Flyway
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input['DbSchemaSchemaSourceArgs'] schema_source: Provides a connector and path at which to find the database schema representation
        :param pulumi.Input[_builtins.str] service: The service associated with schema
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[_builtins.str] type: Type of the database schema. Valid values are: SCRIPT, REPOSITORY
        """
        pulumi.set(__self__, "identifier", identifier)
        pulumi.set(__self__, "org_id", org_id)
        pulumi.set(__self__, "project_id", project_id)
        if changelog_script is not None:
            pulumi.set(__self__, "changelog_script", changelog_script)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if migration_type is not None:
            pulumi.set(__self__, "migration_type", migration_type)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if schema_source is not None:
            pulumi.set(__self__, "schema_source", schema_source)
        if service is not None:
            pulumi.set(__self__, "service", service)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="changelogScript")
    def changelog_script(self) -> Optional[pulumi.Input['DbSchemaChangelogScriptArgs']]:
        """
        Configuration to clone changeSets using script
        """
        return pulumi.get(self, "changelog_script")

    @changelog_script.setter
    def changelog_script(self, value: Optional[pulumi.Input['DbSchemaChangelogScriptArgs']]):
        pulumi.set(self, "changelog_script", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="migrationType")
    def migration_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        DB Migration tool type. Valid values are: Liquibase, Flyway
        """
        return pulumi.get(self, "migration_type")

    @migration_type.setter
    def migration_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "migration_type", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="schemaSource")
    def schema_source(self) -> Optional[pulumi.Input['DbSchemaSchemaSourceArgs']]:
        """
        Provides a connector and path at which to find the database schema representation
        """
        return pulumi.get(self, "schema_source")

    @schema_source.setter
    def schema_source(self, value: Optional[pulumi.Input['DbSchemaSchemaSourceArgs']]):
        pulumi.set(self, "schema_source", value)

    @_builtins.property
    @pulumi.getter
    def service(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The service associated with schema
        """
        return pulumi.get(self, "service")

    @service.setter
    def service(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "service", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Type of the database schema. Valid values are: SCRIPT, REPOSITORY
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.input_type
class _DbSchemaState:
    def __init__(__self__, *,
                 changelog_script: Optional[pulumi.Input['DbSchemaChangelogScriptArgs']] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 migration_type: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 schema_source: Optional[pulumi.Input['DbSchemaSchemaSourceArgs']] = None,
                 service: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering DbSchema resources.
        :param pulumi.Input['DbSchemaChangelogScriptArgs'] changelog_script: Configuration to clone changeSets using script
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] migration_type: DB Migration tool type. Valid values are: Liquibase, Flyway
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input['DbSchemaSchemaSourceArgs'] schema_source: Provides a connector and path at which to find the database schema representation
        :param pulumi.Input[_builtins.str] service: The service associated with schema
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[_builtins.str] type: Type of the database schema. Valid values are: SCRIPT, REPOSITORY
        """
        if changelog_script is not None:
            pulumi.set(__self__, "changelog_script", changelog_script)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if migration_type is not None:
            pulumi.set(__self__, "migration_type", migration_type)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if schema_source is not None:
            pulumi.set(__self__, "schema_source", schema_source)
        if service is not None:
            pulumi.set(__self__, "service", service)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter(name="changelogScript")
    def changelog_script(self) -> Optional[pulumi.Input['DbSchemaChangelogScriptArgs']]:
        """
        Configuration to clone changeSets using script
        """
        return pulumi.get(self, "changelog_script")

    @changelog_script.setter
    def changelog_script(self, value: Optional[pulumi.Input['DbSchemaChangelogScriptArgs']]):
        pulumi.set(self, "changelog_script", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="migrationType")
    def migration_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        DB Migration tool type. Valid values are: Liquibase, Flyway
        """
        return pulumi.get(self, "migration_type")

    @migration_type.setter
    def migration_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "migration_type", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="schemaSource")
    def schema_source(self) -> Optional[pulumi.Input['DbSchemaSchemaSourceArgs']]:
        """
        Provides a connector and path at which to find the database schema representation
        """
        return pulumi.get(self, "schema_source")

    @schema_source.setter
    def schema_source(self, value: Optional[pulumi.Input['DbSchemaSchemaSourceArgs']]):
        pulumi.set(self, "schema_source", value)

    @_builtins.property
    @pulumi.getter
    def service(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The service associated with schema
        """
        return pulumi.get(self, "service")

    @service.setter
    def service(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "service", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Type of the database schema. Valid values are: SCRIPT, REPOSITORY
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.type_token("harness:platform/dbSchema:DbSchema")
class DbSchema(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 changelog_script: Optional[pulumi.Input[Union['DbSchemaChangelogScriptArgs', 'DbSchemaChangelogScriptArgsDict']]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 migration_type: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 schema_source: Optional[pulumi.Input[Union['DbSchemaSchemaSourceArgs', 'DbSchemaSchemaSourceArgsDict']]] = None,
                 service: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Resource for creating a Harness DBDevOps Schema.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        default_type_test = harness.platform.DbSchema("default_type_test",
            identifier="identifier",
            org_id="org_id",
            project_id="project_id",
            name="name",
            service="service1",
            tags=[
                "foo:bar",
                "bar:foo",
            ],
            schema_source={
                "connector": "gitConnector",
                "repo": "TestRepo",
                "location": "db/example-changelog.yaml",
                "archive_path": "path/to/archive.zip",
            })
        liquibase_repository_test = harness.platform.DbSchema("liquibase_repository_test",
            identifier="identifier",
            org_id="org_id",
            project_id="project_id",
            name="name",
            service="service1",
            type="Repository",
            migration_type="Liquibase",
            tags=[
                "foo:bar",
                "bar:foo",
            ],
            schema_source={
                "connector": "gitConnector",
                "repo": "TestRepo",
                "location": "db/example-changelog.yaml",
                "archive_path": "path/to/archive.zip",
            })
        liquibase_script_test = harness.platform.DbSchema("liquibase_script_test",
            identifier="identifier",
            org_id="org_id",
            project_id="project_id",
            name="name",
            migration_type="Liquibase",
            service="service1",
            type="Script",
            tags=[
                "foo:bar",
                "bar:foo",
            ],
            changelog_script={
                "image": "plugins/image",
                "command": "echo \\\\\\"hello dbops\\\\\\"",
                "shell": "sh/bash",
                "location": "db/example-changelog.yaml",
            })
        flyway_repository_test = harness.platform.DbSchema("flyway_repository_test",
            identifier="identifier",
            org_id="org_id",
            project_id="project_id",
            name="name",
            service="service1",
            type="Repository",
            migration_type="Flyway",
            tags=[
                "foo:bar",
                "bar:foo",
            ],
            schema_source={
                "connector": "gitConnector",
                "repo": "TestRepo",
                "location": "db/flyway/migrations",
                "toml": "db/flyway.toml",
                "archive_path": "path/to/archive.zip",
            })
        flyway_script_test = harness.platform.DbSchema("flyway_script_test",
            identifier="identifier",
            org_id="org_id",
            project_id="project_id",
            name="name",
            migration_type="Flyway",
            service="service1",
            type="Script",
            tags=[
                "foo:bar",
                "bar:foo",
            ],
            changelog_script={
                "image": "plugins/image",
                "command": "echo \\\\\\"hello dbops\\\\\\"",
                "shell": "sh/bash",
                "location": "db/flyway/migrations",
                "toml": "db/flyway.toml",
            })
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import project level db schema

        ```sh
        $ pulumi import harness:platform/dbSchema:DbSchema example <org_id>/<project_id>/<db_schema_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['DbSchemaChangelogScriptArgs', 'DbSchemaChangelogScriptArgsDict']] changelog_script: Configuration to clone changeSets using script
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] migration_type: DB Migration tool type. Valid values are: Liquibase, Flyway
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Union['DbSchemaSchemaSourceArgs', 'DbSchemaSchemaSourceArgsDict']] schema_source: Provides a connector and path at which to find the database schema representation
        :param pulumi.Input[_builtins.str] service: The service associated with schema
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[_builtins.str] type: Type of the database schema. Valid values are: SCRIPT, REPOSITORY
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DbSchemaArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating a Harness DBDevOps Schema.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        default_type_test = harness.platform.DbSchema("default_type_test",
            identifier="identifier",
            org_id="org_id",
            project_id="project_id",
            name="name",
            service="service1",
            tags=[
                "foo:bar",
                "bar:foo",
            ],
            schema_source={
                "connector": "gitConnector",
                "repo": "TestRepo",
                "location": "db/example-changelog.yaml",
                "archive_path": "path/to/archive.zip",
            })
        liquibase_repository_test = harness.platform.DbSchema("liquibase_repository_test",
            identifier="identifier",
            org_id="org_id",
            project_id="project_id",
            name="name",
            service="service1",
            type="Repository",
            migration_type="Liquibase",
            tags=[
                "foo:bar",
                "bar:foo",
            ],
            schema_source={
                "connector": "gitConnector",
                "repo": "TestRepo",
                "location": "db/example-changelog.yaml",
                "archive_path": "path/to/archive.zip",
            })
        liquibase_script_test = harness.platform.DbSchema("liquibase_script_test",
            identifier="identifier",
            org_id="org_id",
            project_id="project_id",
            name="name",
            migration_type="Liquibase",
            service="service1",
            type="Script",
            tags=[
                "foo:bar",
                "bar:foo",
            ],
            changelog_script={
                "image": "plugins/image",
                "command": "echo \\\\\\"hello dbops\\\\\\"",
                "shell": "sh/bash",
                "location": "db/example-changelog.yaml",
            })
        flyway_repository_test = harness.platform.DbSchema("flyway_repository_test",
            identifier="identifier",
            org_id="org_id",
            project_id="project_id",
            name="name",
            service="service1",
            type="Repository",
            migration_type="Flyway",
            tags=[
                "foo:bar",
                "bar:foo",
            ],
            schema_source={
                "connector": "gitConnector",
                "repo": "TestRepo",
                "location": "db/flyway/migrations",
                "toml": "db/flyway.toml",
                "archive_path": "path/to/archive.zip",
            })
        flyway_script_test = harness.platform.DbSchema("flyway_script_test",
            identifier="identifier",
            org_id="org_id",
            project_id="project_id",
            name="name",
            migration_type="Flyway",
            service="service1",
            type="Script",
            tags=[
                "foo:bar",
                "bar:foo",
            ],
            changelog_script={
                "image": "plugins/image",
                "command": "echo \\\\\\"hello dbops\\\\\\"",
                "shell": "sh/bash",
                "location": "db/flyway/migrations",
                "toml": "db/flyway.toml",
            })
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import project level db schema

        ```sh
        $ pulumi import harness:platform/dbSchema:DbSchema example <org_id>/<project_id>/<db_schema_id>
        ```

        :param str resource_name: The name of the resource.
        :param DbSchemaArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DbSchemaArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 changelog_script: Optional[pulumi.Input[Union['DbSchemaChangelogScriptArgs', 'DbSchemaChangelogScriptArgsDict']]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 migration_type: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 schema_source: Optional[pulumi.Input[Union['DbSchemaSchemaSourceArgs', 'DbSchemaSchemaSourceArgsDict']]] = None,
                 service: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DbSchemaArgs.__new__(DbSchemaArgs)

            __props__.__dict__["changelog_script"] = changelog_script
            __props__.__dict__["description"] = description
            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__.__dict__["identifier"] = identifier
            __props__.__dict__["migration_type"] = migration_type
            __props__.__dict__["name"] = name
            if org_id is None and not opts.urn:
                raise TypeError("Missing required property 'org_id'")
            __props__.__dict__["org_id"] = org_id
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["schema_source"] = schema_source
            __props__.__dict__["service"] = service
            __props__.__dict__["tags"] = tags
            __props__.__dict__["type"] = type
        super(DbSchema, __self__).__init__(
            'harness:platform/dbSchema:DbSchema',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            changelog_script: Optional[pulumi.Input[Union['DbSchemaChangelogScriptArgs', 'DbSchemaChangelogScriptArgsDict']]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            migration_type: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            schema_source: Optional[pulumi.Input[Union['DbSchemaSchemaSourceArgs', 'DbSchemaSchemaSourceArgsDict']]] = None,
            service: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            type: Optional[pulumi.Input[_builtins.str]] = None) -> 'DbSchema':
        """
        Get an existing DbSchema resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['DbSchemaChangelogScriptArgs', 'DbSchemaChangelogScriptArgsDict']] changelog_script: Configuration to clone changeSets using script
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] migration_type: DB Migration tool type. Valid values are: Liquibase, Flyway
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Union['DbSchemaSchemaSourceArgs', 'DbSchemaSchemaSourceArgsDict']] schema_source: Provides a connector and path at which to find the database schema representation
        :param pulumi.Input[_builtins.str] service: The service associated with schema
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[_builtins.str] type: Type of the database schema. Valid values are: SCRIPT, REPOSITORY
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DbSchemaState.__new__(_DbSchemaState)

        __props__.__dict__["changelog_script"] = changelog_script
        __props__.__dict__["description"] = description
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["migration_type"] = migration_type
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["schema_source"] = schema_source
        __props__.__dict__["service"] = service
        __props__.__dict__["tags"] = tags
        __props__.__dict__["type"] = type
        return DbSchema(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="changelogScript")
    def changelog_script(self) -> pulumi.Output[Optional['outputs.DbSchemaChangelogScript']]:
        """
        Configuration to clone changeSets using script
        """
        return pulumi.get(self, "changelog_script")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="migrationType")
    def migration_type(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        DB Migration tool type. Valid values are: Liquibase, Flyway
        """
        return pulumi.get(self, "migration_type")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="schemaSource")
    def schema_source(self) -> pulumi.Output[Optional['outputs.DbSchemaSchemaSource']]:
        """
        Provides a connector and path at which to find the database schema representation
        """
        return pulumi.get(self, "schema_source")

    @_builtins.property
    @pulumi.getter
    def service(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The service associated with schema
        """
        return pulumi.get(self, "service")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Type of the database schema. Valid values are: SCRIPT, REPOSITORY
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['AddUserToGroupArgs', 'AddUserToGroup']

@pulumi.input_type
class AddUserToGroupArgs:
    def __init__(__self__, *,
                 group_id: pulumi.Input[_builtins.str],
                 user_id: pulumi.Input[_builtins.str]):
        """
        The set of arguments for constructing a AddUserToGroup resource.
        :param pulumi.Input[_builtins.str] group_id: The name of the user.
        :param pulumi.Input[_builtins.str] user_id: Unique identifier of the user.
        """
        pulumi.set(__self__, "group_id", group_id)
        pulumi.set(__self__, "user_id", user_id)

    @_builtins.property
    @pulumi.getter(name="groupId")
    def group_id(self) -> pulumi.Input[_builtins.str]:
        """
        The name of the user.
        """
        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "group_id", value)

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the user.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "user_id", value)


@pulumi.input_type
class _AddUserToGroupState:
    def __init__(__self__, *,
                 group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 user_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering AddUserToGroup resources.
        :param pulumi.Input[_builtins.str] group_id: The name of the user.
        :param pulumi.Input[_builtins.str] user_id: Unique identifier of the user.
        """
        if group_id is not None:
            pulumi.set(__self__, "group_id", group_id)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)

    @_builtins.property
    @pulumi.getter(name="groupId")
    def group_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the user.
        """
        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "group_id", value)

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the user.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_id", value)


@pulumi.type_token("harness:index/addUserToGroup:AddUserToGroup")
class AddUserToGroup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 user_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Resource for adding a user to a group.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        example_user = harness.get_user(email="testuser@example.com")
        admin = harness.UserGroup("admin", name="admin")
        example_add_user_to_groups = harness.AddUserToGroup("example_add_user_to_groups",
            group_id=admin.id,
            user_id=test["id"])
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import using the Harness user and user group id

        ```sh
        $ pulumi import harness:index/addUserToGroup:AddUserToGroup example_admin <user_id>/<group_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] group_id: The name of the user.
        :param pulumi.Input[_builtins.str] user_id: Unique identifier of the user.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AddUserToGroupArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for adding a user to a group.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        example_user = harness.get_user(email="testuser@example.com")
        admin = harness.UserGroup("admin", name="admin")
        example_add_user_to_groups = harness.AddUserToGroup("example_add_user_to_groups",
            group_id=admin.id,
            user_id=test["id"])
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import using the Harness user and user group id

        ```sh
        $ pulumi import harness:index/addUserToGroup:AddUserToGroup example_admin <user_id>/<group_id>
        ```

        :param str resource_name: The name of the resource.
        :param AddUserToGroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AddUserToGroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 user_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AddUserToGroupArgs.__new__(AddUserToGroupArgs)

            if group_id is None and not opts.urn:
                raise TypeError("Missing required property 'group_id'")
            __props__.__dict__["group_id"] = group_id
            if user_id is None and not opts.urn:
                raise TypeError("Missing required property 'user_id'")
            __props__.__dict__["user_id"] = user_id
        super(AddUserToGroup, __self__).__init__(
            'harness:index/addUserToGroup:AddUserToGroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            group_id: Optional[pulumi.Input[_builtins.str]] = None,
            user_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'AddUserToGroup':
        """
        Get an existing AddUserToGroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] group_id: The name of the user.
        :param pulumi.Input[_builtins.str] user_id: Unique identifier of the user.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AddUserToGroupState.__new__(_AddUserToGroupState)

        __props__.__dict__["group_id"] = group_id
        __props__.__dict__["user_id"] = user_id
        return AddUserToGroup(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="groupId")
    def group_id(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the user.
        """
        return pulumi.get(self, "group_id")

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the user.
        """
        return pulumi.get(self, "user_id")

